@@ -17,6 +17,8 @@ function(identity, rank, winners, losers, fitted=FALSE) {
 	}
 	x <- x[!is.na(y)]
 	y <- y[!is.na(y)]
+	CI.upper <- CI.upper[!is.na(y)]
+	CI.lower <- CI.lower[!is.na(y)]
 
 	plot(x,y, xlab="Difference in rank", ylab="Probability that higher rank wins", ylim=c(min(0.5,min(y)),1), pch=20, cex=2)
 	arrows(x,CI.lower,x,CI.upper,length=0.1,angle=90,code=3)
